=== modified file 'NEWS'
--- NEWS	2010-07-16 13:06:33 +0000
+++ NEWS	2010-07-16 15:20:17 +0000
@@ -14,12 +14,19 @@
 Compatibility Breaks
 ********************
 
+* `FileInWrongBranch` is deprecated in favour of `PathNotChild` and no
+  longer raised.
+  (Martin Pool)
+
 New Features
 ************
 
 Bug Fixes
 *********
 
+* `PathNotChild` should not give a traceback.
+  (Martin Pool, #98735)
+
 Improvements
 ************
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2010-07-16 13:29:07 +0000
+++ bzrlib/builtins.py	2010-07-16 15:20:17 +0000
@@ -77,12 +77,8 @@
 
 def tree_files(file_list, default_branch=u'.', canonicalize=True,
     apply_view=True):
-    try:
-        return internal_tree_files(file_list, default_branch, canonicalize,
-            apply_view)
-    except errors.FileInWrongBranch, e:
-        raise errors.BzrCommandError("%s is not in the same branch as %s" %
-                                     (e.path, file_list[0]))
+    return internal_tree_files(file_list, default_branch, canonicalize,
+        apply_view)
 
 
 def tree_files_for_add(file_list):

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2010-07-16 13:29:07 +0000
+++ bzrlib/diff.py	2010-07-16 15:20:17 +0000
@@ -420,12 +420,9 @@
 
     # Get the specific files (all files is None, no files is [])
     if make_paths_wt_relative and working_tree is not None:
-        try:
-            other_paths = working_tree.safe_relpath_files(
-                other_paths,
-                apply_view=apply_view)
-        except errors.FileInWrongBranch:
-            raise errors.BzrCommandError("Files are in different branches")
+        other_paths = working_tree.safe_relpath_files(
+            other_paths,
+            apply_view=apply_view)
     specific_files.extend(other_paths)
     if len(specific_files) == 0:
         specific_files = None

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2010-07-09 16:16:11 +0000
+++ bzrlib/errors.py	2010-07-16 13:53:26 +0000
@@ -680,7 +680,7 @@
 
     _fmt = 'Path "%(path)s" is not a child of path "%(base)s"%(extra)s'
 
-    internal_error = True
+    internal_error = False
 
     def __init__(self, path, base, extra=None):
         BzrError.__init__(self)
@@ -782,6 +782,8 @@
 
     _fmt = 'File "%(path)s" is not in branch %(branch_base)s.'
 
+    # use PathNotChild instead
+    @symbol_versioning.deprecated_method(symbol_versioning.deprecated_in((2, 3, 0)))
     def __init__(self, branch, path):
         BzrError.__init__(self)
         self.branch = branch

=== modified file 'bzrlib/tests/blackbox/test_add.py'
--- bzrlib/tests/blackbox/test_add.py	2010-02-23 07:43:11 +0000
+++ bzrlib/tests/blackbox/test_add.py	2010-07-16 13:53:26 +0000
@@ -23,6 +23,9 @@
     osutils,
     tests,
     )
+from bzrlib.tests import (
+    script,
+    )
 
 
 def load_tests(standard_tests, module, loader):
@@ -217,3 +220,14 @@
         os.symlink(osutils.abspath('target'), 'tree/link')
         out = self.run_bzr(['add', 'tree/link'])[0]
         self.assertEquals(out, 'adding link\n')
+
+    def test_add_not_child(self):
+        # https://bugs.launchpad.net/bzr/+bug/98735
+        sr = script.ScriptRunner()
+        self.make_branch_and_tree('tree1')
+        self.make_branch_and_tree('tree2')
+        self.build_tree(['tree1/a', 'tree2/b'])
+        sr.run_script(self, '''
+        $ bzr add tree1/a tree2/b
+        2>bzr: ERROR: Path "...tree2/b" is not a child of path "...tree1"
+        ''')

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2010-07-16 13:29:07 +0000
+++ bzrlib/workingtree.py	2010-07-16 15:20:17 +0000
@@ -400,16 +400,12 @@
         else:
             fixer = self.relpath
         for filename in file_list:
-            try:
-                relpath = fixer(osutils.dereference_path(filename))
-                if view_files and not osutils.is_inside_any(view_files, relpath):
-                    raise errors.FileOutsideView(filename, view_files)
-                new_list.append(relpath)
-            except errors.PathNotChild:
-                raise errors.FileInWrongBranch(self.branch, filename)
+            relpath = fixer(osutils.dereference_path(filename))
+            if view_files and not osutils.is_inside_any(view_files, relpath):
+                raise errors.FileOutsideView(filename, view_files)
+            new_list.append(relpath)
         return new_list
 
-
     @staticmethod
     def open_downlevel(path=None):
         """Open an unsupported working tree.

